==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/invoice/ShopApplicationQueryResponse.java <==
package eleme.openapi.sdk.api.entity.invoice;

import java.util.*;
import java.math.BigDecimal;

public class ShopApplicationQueryResponse{

    /**
     * 申请单编号
     */
    private String applicationNo;
    public String getApplicationNo() {
        return applicationNo;
    }
    public void setApplicationNo(String applicationNo) {
        this.applicationNo = applicationNo;
    }
    
    /**
     * 店铺ID
     */
    private Long shopId;
    public Long getShopId() {
        return shopId;
    }
    public void setShopId(Long shopId) {
        this.shopId = shopId;
    }
    
    /**
     * 发票材质
     */
    private String invoiceMaterial;
    public String getInvoiceMaterial() {
        return invoiceMaterial;
    }
    public void setInvoiceMaterial(String invoiceMaterial) {
        this.invoiceMaterial = invoiceMaterial;
    }
    
    /**
     * 发票种类
     */
    private String invoiceClass;
    public String getInvoiceClass() {
        return invoiceClass;
    }
    public void setInvoiceClass(String invoiceClass) {
        this.invoiceClass = invoiceClass;
    }
    
    /**
     * 购方抬头
     */
    private NaposUserTitle buyerTitle;
    public NaposUserTitle getBuyerTitle() {
        return buyerTitle;
    }
    public void setBuyerTitle(NaposUserTitle buyerTitle) {
        this.buyerTitle = buyerTitle;
    }
    
    /**
     * 申请状态
     */
    private String status;
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    
    /**
     * 订单列表
     */
    private List<ElemeInvoiceOrderInfo> orderList;
    public List<ElemeInvoiceOrderInfo> getOrderList() {
        return orderList;
    }
    public void setOrderList(List<ElemeInvoiceOrderInfo> orderList) {
        this.orderList = orderList;
    }
    
    /**
     * 开票总金额
     */
    private BigDecimal totalInvoiceAmount;
    public BigDecimal getTotalInvoiceAmount() {
        return totalInvoiceAmount;
    }
    public void setTotalInvoiceAmount(BigDecimal totalInvoiceAmount) {
        this.totalInvoiceAmount = totalInvoiceAmount;
    }
    
    /**
     * 购方用户联系方式
     */
    private NaposUserContact buyerContact;
    public NaposUserContact getBuyerContact() {
        return buyerContact;
    }
    public void setBuyerContact(NaposUserContact buyerContact) {
        this.buyerContact = buyerContact;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/invoice/ShopApplicationQueryResponse.java <==
package eleme.openapi.sdk.api.entity.invoice;

import eleme.openapi.sdk.api.enumeration.invoice.*;
import eleme.openapi.sdk.api.entity.invoice.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class ShopApplicationQueryResponse{

    /**
     * 申请单编号
     */
    private String applicationNo;
    public String getApplicationNo() {
        return applicationNo;
    }
    public void setApplicationNo(String applicationNo) {
        this.applicationNo = applicationNo;
    }
    
    /**
     * 店铺ID
     */
    private Long shopId;
    public Long getShopId() {
        return shopId;
    }
    public void setShopId(Long shopId) {
        this.shopId = shopId;
    }
    
    /**
     * 发票材质
     */
    private String invoiceMaterial;
    public String getInvoiceMaterial() {
        return invoiceMaterial;
    }
    public void setInvoiceMaterial(String invoiceMaterial) {
        this.invoiceMaterial = invoiceMaterial;
    }
    
    /**
     * 发票种类
     */
    private String invoiceClass;
    public String getInvoiceClass() {
        return invoiceClass;
    }
    public void setInvoiceClass(String invoiceClass) {
        this.invoiceClass = invoiceClass;
    }
    
    /**
     * 购方抬头
     */
    private NaposUserTitle buyerTitle;
    public NaposUserTitle getBuyerTitle() {
        return buyerTitle;
    }
    public void setBuyerTitle(NaposUserTitle buyerTitle) {
        this.buyerTitle = buyerTitle;
    }
    
    /**
     * 申请状态
     */
    private String status;
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    
    /**
     * 订单列表
     */
    private List<ElemeInvoiceOrderInfo> orderList;
    public List<ElemeInvoiceOrderInfo> getOrderList() {
        return orderList;
    }
    public void setOrderList(List<ElemeInvoiceOrderInfo> orderList) {
        this.orderList = orderList;
    }
    
    /**
     * 开票总金额
     */
    private BigDecimal totalInvoiceAmount;
    public BigDecimal getTotalInvoiceAmount() {
        return totalInvoiceAmount;
    }
    public void setTotalInvoiceAmount(BigDecimal totalInvoiceAmount) {
        this.totalInvoiceAmount = totalInvoiceAmount;
    }
    
    /**
     * 购方用户联系方式
     */
    private NaposUserContact buyerContact;
    public NaposUserContact getBuyerContact() {
        return buyerContact;
    }
    public void setBuyerContact(NaposUserContact buyerContact) {
        this.buyerContact = buyerContact;
    }
    
}
